aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
authorc-parsons <cparsons@google.com>2019-05-28 17:54:22 -0400
committerGitHub <noreply@github.com>2019-05-28 17:54:22 -0400
commit202db59eccd13c5c9a98b4c905ed300eb2785e10 (patch)
treec6e16a41e5ab22b1385b6a56e68001eb49c9a7f2 /tests
parent5c80706f70186507a262ef756fff80b2fde743e9 (diff)
downloadbazel-skylib-202db59eccd13c5c9a98b4c905ed300eb2785e10.tar.gz
Make sets.bzl point to new_sets.bzl instead of old_sets.bzl (#158)
* Make sets.bzl point to new_sets.bzl instead of old_sets.bzl new_sets.bzl and old_sets.bzl should be removed in the following skylib release. Fixes #155. * update and rename test suites
Diffstat (limited to 'tests')
-rw-r--r--tests/BUILD10
-rw-r--r--tests/old_sets_tests.bzl (renamed from tests/sets_tests.bzl)10
2 files changed, 10 insertions, 10 deletions
diff --git a/tests/BUILD b/tests/BUILD
index 0b1706f..e27cdd5 100644
--- a/tests/BUILD
+++ b/tests/BUILD
@@ -3,11 +3,11 @@ load(":build_test_tests.bzl", "build_test_test_suite")
load(":collections_tests.bzl", "collections_test_suite")
load(":dicts_tests.bzl", "dicts_test_suite")
load(":maprule_tests.bzl", "maprule_test_suite")
+load(":old_sets_tests.bzl", "old_sets_test_suite")
load(":new_sets_tests.bzl", "new_sets_test_suite")
load(":partial_tests.bzl", "partial_test_suite")
load(":paths_tests.bzl", "paths_test_suite")
load(":selects_tests.bzl", "selects_test_suite")
-load(":sets_tests.bzl", "sets_test_suite")
load(":shell_tests.bzl", "shell_args_test_gen", "shell_test_suite")
load(":structs_tests.bzl", "structs_test_suite")
load(":types_tests.bzl", "types_test_suite")
@@ -29,16 +29,16 @@ dicts_test_suite()
maprule_test_suite()
+old_sets_test_suite()
+
+new_sets_test_suite()
+
partial_test_suite()
paths_test_suite()
selects_test_suite()
-sets_test_suite()
-
-new_sets_test_suite()
-
shell_test_suite()
structs_test_suite()
diff --git a/tests/sets_tests.bzl b/tests/old_sets_tests.bzl
index f7d99bb..638a9c3 100644
--- a/tests/sets_tests.bzl
+++ b/tests/old_sets_tests.bzl
@@ -12,9 +12,9 @@
# See the License for the specific language governing permissions and
# limitations under the License.
-"""Unit tests for sets.bzl."""
+"""Unit tests for old_sets.bzl."""
-load("//lib:sets.bzl", "sets")
+load("//lib:old_sets.bzl", "sets")
load("//lib:unittest.bzl", "asserts", "unittest")
def _is_equal_test(ctx):
@@ -140,10 +140,10 @@ def _difference_test(ctx):
difference_test = unittest.make(_difference_test)
-def sets_test_suite():
- """Creates the test targets and test suite for sets.bzl tests."""
+def old_sets_test_suite():
+ """Creates the test targets and test suite for old_sets.bzl tests."""
unittest.suite(
- "sets_tests",
+ "old_sets_tests",
disjoint_test,
intersection_test,
is_equal_test,